package de.jpv.openinidea.client;

/*
 *  Copyright 2007 Jens Vo.
 *
 *  Licensed under the Apache License version 2.0 (the "License").
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.List;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.UIManager;

/**
 * The <code>ProjectSelector</code> is responsible for displaying a popup menu
 * containing a list of all projects currently opened in IntelliJ IDEA.
 */
public class ProjectSelector extends JPopupMenu {

  private static final Color DARK_BLUE = new Color(0, 0, 128);
  private static Color defaultColor;

  static {
    try {
      UIManager.setLookAndFeel(
        UIManager.getSystemLookAndFeelClassName());
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }

  private final MouseListener selectorMouseListener = new MouseAdapter() {
    @Override
    public void mouseEntered(final MouseEvent event) {
      if (defaultColor == null) {
        defaultColor = event.getComponent().getBackground();
      }
      event.getComponent().setBackground(DARK_BLUE);
      event.getComponent().setForeground(Color.WHITE);
    }

    @Override
    public void mouseExited(final MouseEvent event) {
      event.getComponent().setBackground(defaultColor);
      event.getComponent().setForeground(Color.BLACK);
    }
  };

  private final ActionListener selectorMenuListener = new ActionListener() {
    public void actionPerformed(final ActionEvent event) {
      ((SelectorEntry) event.getSource()).select();
      System.out.println("Popup menu item ["
                         + event.getActionCommand() + "] was pressed.");
      ProjectSelector.this.setVisible(false);
    }
  };

  private class SelectorEntry extends JMenuItem {

    private final int pos;

    private SelectorEntry(final String s, final int pos) {
      super(s);
      this.pos = pos;
      this.addMouseListener(ProjectSelector.this.selectorMouseListener);
      this.addActionListener(ProjectSelector.this.selectorMenuListener);
    }

    private void select() {
      ProjectSelector.this.selection = pos;
    }
  }

  private int selection;

  /**
   * Public constructor.
   *
   * @param entryLabels A <code>List</code> of <code>Project</code> names
   */
  public ProjectSelector(final List<String> entryLabels) {
    add("Select Project");
    addSeparator();
    for (final String entryLabel : entryLabels) {
      add(new SelectorEntry(entryLabel, selection++));
    }
    selection = -1;
  }

  /**
   * This method returns the index of the selected menu entry if one has been
   * selected.
   *
   * @return The index of the menu entry selected (if any); -1 otherwise.
   */
  public int getSelection() {
    return selection;
  }

}
