package de.jpv.openinidea.shared;

/*
 *  Copyright 2007 Jens Vo.
 *
 *  Licensed under the Apache License version 2.0 (the "License").
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

/**
 * The <code>Config</code> class is used to provide configuration shared by the
 * client and server components of the OpenInIDEA plugin.
 */
public class Config {

  private static final int DEFAULT_PORT = 3728;
  private static final String PORT_KEY = "openInIDEA.port";

  private static final int PORT = initPort();

  private static int initPort() {
    String port = System.getProperty(PORT_KEY);
    try {
      return port != null ? Integer.parseInt(port) : DEFAULT_PORT;
    }
    catch (NumberFormatException e) {
      e.printStackTrace();
      return DEFAULT_PORT;
    }
  }

  /**
   * This method will return the port number over which the client and server
   * component of the OpenInIDEA communicate. By default, this is port 3728;
   * it may be customized by passing it to the VM (of both the client and the
   * server) via the environment variable <code>openInIDEA.port</code>.
   *
   * @return Either the value of the <code>openInIDEA.port</code> environment
   * variable or - if this value is not set - the default port 3728.
   */
  public static int getPort() {
    return PORT;
  }

  private Config() {
  }

}
