package de.jpv.openinidea.shared;

/*
 *  Copyright 2007 Jens Vo.
 *
 *  Licensed under the Apache License version 2.0 (the "License").
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

import java.io.Serializable;

/**
 * The <code>Request</code> class is the vehicle of the communication between
 * the client and the server component of the OpenInIDEA plugin. It allows to
 * specify the path of a file to be opened (mandatory) and the project URL of
 * a currently opened IDEA project (optional).
 */
public class Request implements Serializable {

  private final String fileName;
  private String projectUrl;

  /**
   * Public constructor.
   *
   * @param fileName The name of the file to be opened in IDEA.
   */
  public Request(final String fileName) {
    this.projectUrl = null;
    this.fileName = fileName;
  }

  /**
   * Public setter method for this <code>Request</code>'s project URL.
   *
   * @param projectUrl The project URL of the IDEA project in which the
   *         specified file should be opened
   */
  public void setProjectUrl(final String projectUrl) {
    this.projectUrl = projectUrl;
  }

  /**
   * Public getter method for this <code>Request</code>'s project URL.
   *
   * @return The project URL of the IDEA project in which the specified file
   *          should be opened
   */
  public String getProjectUrl() {
    return projectUrl;
  }

  /**
   * Public getter method for this <code>Request</code>'s file path.
   *
   * @return The path of the file to be opened in IDEA
   */
  public String getFileName() {
    return fileName;
  }

}
